import { useCallback, useState, useEffect } from 'react';
import { stringify } from 'querystring';
import { notification } from 'antd';
import request from '@/utils/request'
import TableList from './TableList';
import Pagination from './Pagination';

export default (props) => {
  const [loading, setLoading] = useState(false)
  const [pageConfig, setPageConfig] = useState({ current: 1, pageSize: 10, total: 0 })
  const [list, setList] = useState()
  const { api, params = {}, ...tableProps } = props
  const paramsStr = stringify({
    ...params,
    pageNum: pageConfig.current,
    pageSize: pageConfig.pageSize,
  })

  const updatePageConfig = useCallback((config) => {
    setPageConfig({
      ...pageConfig,
      ...config
    })
  }, [pageConfig])

  const handlePageChange = (current, pageSize) => {
    const config = pageSize ? { current, pageSize } : { current }
    updatePageConfig(config)
  }

  useEffect(() => {
    const url = `${api.url}?${paramsStr}`
    setLoading(true)
    request({...api, url}).then((res) => {
      const {current, total, records = []} = res
      setLoading(false)
      setList(records)
      updatePageConfig({current, total})
    }).catch((err) => {
      console.error(err)
      setLoading(false)
      notification.warn({ message: err.message })
    })
  }, [paramsStr, api])

  return (
    <>
      <TableList loading={loading} dataSource={list} {...tableProps} />
      <Pagination {...pageConfig} onChange={handlePageChange} />
    </>
  )
};
